#! /usr/bin/env python
'''Choose Context class for use as default testing context
'''
from OpenGLContext.glutvrmltestingcontext import BaseContext
from OpenGLContext.scenegraph.basenodes import *
from vrml.vrml97 import nodetypes
from OpenGLContext.events import mouseevents
import Image

from OpenGLContext.resources import red_arrow_right_png
from OpenGLContext.resources import green_arrow_right_png
from OpenGLContext.resources import available_contexts_txt
from OpenGLContext.resources import disk_icon_png
from OpenGLContext.resources import disk_icon_hi_png

class ChoiceContext( BaseContext ):
	currentChoice = 0
	def loadChoices( self ):
		"""See which contexts are available"""
		choices = []
		for line in available_contexts_txt.data.splitlines():
			line = line.strip()
			if line:
				line = line.split( '\t' )
				if len(line) == 2:
					choices.append( (line[0],line[1]))
		return choices
	def nameForContextType( self, current ):
		if current:
			for index,(key,name) in enumerate( self.choices ):
				if key == current:
					return (index,(key,name))
		return (-1,(current,''))
	def OnInit( self ):
		"""Setup callbacks and build geometry for rendering"""
		self.choices = self.loadChoices()
		current = self.getDefaultContextType()
		index,(key,name) = self.nameForContextType( current )
		if index > -1:
			self.currentChoice = index
		fontStyle = FontStyle(
			size = .75,
			family = "SANS",
			justify = "LEFT",
			#format = "bitmap",
		)
		self.texture1 = ImageTexture()
		self.texture1.loadFromData( red_arrow_right_png.data )
		self.texture2 = ImageTexture()
		self.texture2.loadFromData( green_arrow_right_png.data )
		self.texture3 = ImageTexture()
		self.texture3.loadFromData( disk_icon_png.data )
		self.texture4 = ImageTexture()
		self.texture4.loadFromData( disk_icon_hi_png.data )
		self.buttonGeometry = IndexedFaceSet(
			coord = Coordinate(
				point = [
					(-.5,.5,0),
					(-.5,-.5,0),
					(.5,-.5,0),
					(.5,.5,0),
				],
			),
			coordIndex = [
				0,1,2,3,
			],
			texCoord = TextureCoordinate(
				point = [
					(0,1),
					(0,0),
					(1,0),
					(1,1),
				],
			),
			texCoordIndex = [
				0,1,2,3
			],
		)
		self.previousButton = MouseOver(
			choice = [
				Shape(
					geometry = self.buttonGeometry,
					appearance = Appearance(
						texture = self.texture1,
					),
				),
				Shape(
					geometry = self.buttonGeometry,
					appearance = Appearance(
						texture = self.texture2,
					),
				),
			],
			whichChoice = 0,
		)
		self.nextButton = MouseOver(
			choice = [
				Shape(
					geometry = self.buttonGeometry,
					appearance = Appearance(
						texture = self.texture1,
					),
				),
				Shape(
					geometry = self.buttonGeometry,
					appearance = Appearance(
						texture = self.texture2,
					),
				),
			],
			whichChoice = 0,
		)
		self.saveButton = MouseOver(
			choice = [
				Shape(
					geometry = self.buttonGeometry,
					appearance = Appearance(
						texture = self.texture3,
					),
				),
				Shape(
					geometry = self.buttonGeometry,
					appearance = Appearance(
						texture = self.texture4,
					),
				),
			],
			whichChoice = 0,
		)
		self.currentChoiceText = 		Text(
			string=[self.choices[self.currentChoice][1]],
			fontStyle = FontStyle(
				justify = "MIDDLE",
			),
		)
		self.savedText = 		Text(
			string=[self.nameForContextType(self.getDefaultContextType())[-1][-1]],
			fontStyle = FontStyle(
				justify = "MIDDLE",
			),
		)

		self.sg = sceneGraph(
			children = [
				SimpleBackground( color = (0,0,.25) ),
				Shape(
					geometry = self.currentChoiceText,
				),
				Transform(
					translation = (2,-1,0),
					children = [
						self.previousButton,
					],
				),
				Transform(
					translation = (-2,-1,0),
					rotation = (0,0,1,3.14159),
					children = [
						self.nextButton,
					],
				),
				Transform(
					translation= (0,-2,0),
					children = [self.saveButton],
				),
				Transform(
					translation= (0,-4,0),
					children = [
						Shape(
							geometry = self.savedText,
						),
					],
				),
				
			],
		)
		self.addEventHandler(
			'mousebutton', 
			node=self.previousButton, 
			button = 0,
			state = 0,
			function = self.OnPrevious,
		)
		self.addEventHandler(
			'mousebutton', 
			node=self.nextButton, 
			button = 0,
			state = 0,
			function = self.OnNext,
		)
		self.addEventHandler(
			'mousebutton', 
			node=self.saveButton, 
			button = 0,
			state = 0,
			function = self.OnSave,
		)
	def OnNext( self, event ):
		"""Clicked the next button"""
		self.currentChoice += 1
		self.currentChoice = self.currentChoice % len( self.choices )
		self.currentChoiceText.string = self.choices[self.currentChoice][1]
		self.triggerRedraw(1)
	def OnPrevious( self, event ):
		"""Clicked the previous button"""
		self.currentChoice -= 1
		self.currentChoice = self.currentChoice % len( self.choices )
		self.currentChoiceText.string = self.choices[self.currentChoice][1]
		self.triggerRedraw(1)
		
	def OnSave( self, event ):
		"""Save current choice to the preferences file"""
		self.setDefaultContextType( self.choices[self.currentChoice][0] )
		self.savedText.string = [ self.choices[self.currentChoice][1] ]
		self.triggerRedraw(1)

def main():
	"""Mainloop redirecting to context's mainloop for operations"""
	return ChoiceContext.ContextMainLoop()

if __name__ == "__main__":
	main()
