'''wxPython-based meta-testing framework...
'''
from OpenGLContext import testingcontext
testingcontext.PREFERENCELIST = ('wx',)
from wxPython.wx import *
import weakref

class TestFrame( wxFrame ):
	"""Base frame for the wx-based test framework

	This is to be reminiscent of the wxPython demo in
	a lot of ways.
		Left-side, a list control with the available tests
		Right-upper side, the Context window, hosted by a panel
		Right-lower side, an output window
	"""
	currentTestIndex = 0
	def __init__(
		self, parent=None, id=-1, title="OpenGLContext Visual Shell",
		pos = wxDefaultPosition, size = (600,450),
		style = wxDEFAULT_FRAME_STYLE, name = "mainframe",
	):
		wxFrame.__init__( self, parent, id, title, pos, size, style, name )
		self.CreateControls( style )
		self.SetIcons( self.context.getDefaultIcons())

	def CreateShellEnvironment( self ):
		"""Create the working shell environment"""
		from OpenGLContext import arrays
		from OpenGLContext.scenegraph import basenodes, extrusions
		from OpenGLContext import utilities, vectorutilities, displaylist
		from OpenGLContext.loaders import vrml97
		from pydispatch import dispatcher
		environment = {
			'load': vrml97.load,
			'dump': vrml97.dump,
			'aload': arrays.load,
			'adump': arrays.dump,
			'frame': weakref.proxy(self),
			'context': weakref.proxy(self.context),
			'DisplayList': displaylist.DisplayList,
			'crossProduct': vectorutilities.crossProduct,
			'crossProduct4':vectorutilities.crossProduct4,
			'magnitude':vectorutilities.magnitude,
			'normalise':vectorutilities.normalise,
			'pointNormal2Plane':utilities.pointNormal2Plane,
			'plane2PointNormal':utilities.plane2PointNormal,
			'rotMatrix':utilities.rotMatrix,
			'dispatcher':dispatcher,
		}
		for module in basenodes, extrusions, arrays:
			for name in dir(module):
				if not environment.has_key( name ):
					environment[name] = getattr( module, name )
		return environment
	def CreateControls( self, style=None ):
		"""Create the controls for the frame"""
		self.shellSplitter = wxSplitterWindow( self, -1, style = wxSP_3DSASH)
		self.CreateContext( self.shellSplitter )
##		self.splitter = wxSplitterWindow(self.shellSplitter, -1, style = wxSP_3DSASH)
##		self.splitter.SplitVertically(
##			self.CreateSelectionControl( self.splitter ),
##			self.CreateContext( self.splitter ),
##			180,
##		)
		self.shellSplitter.SplitHorizontally(
##			self.splitter,
			self.context,
			self.CreateShellControl( self.shellSplitter ),
			-180,
		)
		self.CreateMenus()
		self.Layout()
	def CreateMenus( self ):
		"""Create our application menu-bars"""
		# Prepare the menu bar
		import wx
		menuBar = wx.MenuBar()

		menuData = [
			('&File', [
				('&Open', 'OnOpenCommand', """Open VRML97 file replacing current scene"""),
				('&Add', 'OnAddCommand', """Add VRML97 file contents to current scene""" ),
				('E&xit', 'OnExitCommand', """Exit the browser"""),
			]),
		]
		for menuName, subElements in menuData:
			menu = wx.Menu()
			for label, method, description in subElements:
				ID = wx.NewId()
				menu.Append( ID, label, description )
				wx.EVT_MENU( self, ID, getattr( self, method) )
			menuBar.Append( menu, menuName )
		self.SetMenuBar(menuBar)
	def OnExitCommand( self, event ):
		"""Exit from the browser"""
		self.Close()
	def OnOpenCommand( self, event ):
		"""Open a file-selection dialog to load a file"""
		import wx, os
		dialog = wx.FileDialog(
			self, message="Choose VRML97 file to replace world",
			defaultDir=os.getcwd(),
			defaultFile="",
			wildcard="*.wrl",
			style=wx.OPEN | wx.CHANGE_DIR
		)
		if dialog.ShowModal() == wx.ID_OK:
			path = dialog.GetPath()
			from OpenGLContext.loaders import vrml97
			scenegraph = vrml97.load( path )
			self.context.scene = scenegraph
	def OnAddCommand( self, event ):
		"""Add VRML97 nodes from a file"""
		
		
	def CreateContext( self, parent ):
		"""Create the VRML browser context"""
		from OpenGLContext.browser import browsercontext
		self.context = browsercontext.BrowserContext( parent )
		return self.context
	def CreateSelectionControl( self, parent ):
		"""Create and populate the test-list control"""
		return wxListCtrl( parent, -1 )
	def CreateShellControl( self, parent ):
		"""Create the base shell control for the testing application"""
		self.shell = UpdatingShell( parent, -1, locals = self.CreateShellEnvironment())
		self.shell.context = self.context
		return self.shell
	def UpdateShellVariables( self, **named ):
		"""Update shell's local variables from named arguments"""
		self.shell.interp.locals.update( named )

try:
	from wx.py import shell
except ImportError:
	from wxPython.lib.PyCrust import shell


class UpdatingShell( shell.Shell ):
	def push(self, command):
		"""Send command to the interpreter for execution."""
		shell.Shell.push( self, command )
		try:
			self.context.triggerRedraw()
		except AttributeError:
			pass
		
		

if __name__ == "__main__":
	class TestApplication (wxPySimpleApp):
		def OnInit(self):
			wxInitAllImageHandlers()
			frame = TestFrame(NULL, -1, "OpenGLContext wxPython tests")
			##frame.LoadContext(  )
			frame.Show (1)
			self.SetTopWindow(frame)
			return 1
	
	app = TestApplication ()
	app.MainLoop()

	

